@@ -11,6 +11,31 @@
 
 from flask import Blueprint
 
+blueprint = Blueprint(
+    "invenio_users_resources",
+    __name__,
+    template_folder="templates",
+    static_folder="static",
+)
+
+
+@blueprint.record_once
+def init(state):
+    """Init app."""
+    app = state.app
+    # Register services - cannot be done in extension because
+    # Invenio-Records-Resources might not have been initialized.
+    rr_ext = app.extensions["invenio-records-resources"]
+    ext = app.extensions["invenio-users-resources"]
+    idx_ext = app.extensions["invenio-indexer"]
+
+    # services
+    rr_ext.registry.register(ext.users_service)
+    rr_ext.registry.register(ext.groups_service)
+
+    idx_ext.registry.register(ext.users_service.indexer, indexer_id="users")
+    idx_ext.registry.register(ext.groups_service.indexer, indexer_id="groups")
+
 
 def create_users_resources_bp(app):
     """Create the users resource blueprint."""
@@ -22,15 +47,3 @@ def create_groups_resources_bp(app):
     """Create the user groups resource blueprint."""
     ext = app.extensions["invenio-users-resources"]
     return ext.groups_resource.as_blueprint()
-
-
-def create_blueprint(app):
-    """Create a blueprint."""
-    blueprint = Blueprint(
-        "invenio_users_resources",
-        __name__,
-        template_folder="templates",
-        static_folder="static",
-    )
-
-    return blueprint
